@@ -8,7 +8,7 @@
 # *
 # * This program is free software; you can redistribute it and/or modify
 # * it under the terms of the GNU General Public License as published by
-# * the Free Software Foundation; either version 2 of the License, or
+# * the Free Software Foundation; either version 3 of the License, or
 # * (at your option) any later version.
 # *
 # * This program is distributed in the hope that it will be useful,
@@ -91,7 +91,7 @@ class TestImportSequence(TestImportBase):
                 'inputRawSequence': self.NUCLEOTIDESEQ1
                 }
         prot2 = self.newProtocol(emprot.ProtImportSequence, **args)
-        prot2.setObjLabel('2_import RNA,\nseq from user\nAmbigous RNA '
+        prot2.setObjLabel('2_import RNA,\nseq from user\nAmbiguous RNA '
                           'alphabet')
         self.launchProtocol(prot2)
         sequence = prot2.outputSequence
